@@ -472,6 +472,11 @@ class Structure:
         with self._get_file_stream(alembic_readme) as stream:
             stream.write(strings.ALEMBIC_README)
 
+    def create_dotenv(self):
+        dotenv = self.files.create_file(".env")
+        with self._get_file_stream(dotenv) as stream:
+            stream.write(strings.DOTENV)
+
     @classmethod
     def create(cls, base_dir: Path, project_name: str, pyproject_toml: PyprojectToml):
         structure = cls(base_dir, project_name, pyproject_toml)
