@@ -589,7 +589,7 @@ def get_application(prefix: str = ""):
         docs_url=f"{{prefix}}/docs",
         redoc_url=f"{{prefix}}/redoc",
     )
-    _app.include_router(routes.router, prefix=f"{{prefix or '/'}}")
+    _app.include_router(routes.router, prefix=f"{{prefix}}")
 
     _app.add_event_handler("startup", create_startup_handler(_app))
     _app.add_event_handler("shutdown", create_shutdown_handler(_app))
@@ -1700,3 +1700,10 @@ formatter = generic
 format = %%(levelname)-5.5s [%%(name)s] %%(message)s
 datefmt = %H:%M:%S
 """
+
+DOTENV = """ENV=
+DB_NAME=
+DB_USER=
+DB_PASSWORD=
+DB_HOST=
+"""
\ No newline at end of file
